#[repr(u8)]pub enum GrammeterStateE {
Reset = 0,
Sync = 1,
Ready = 2,
SyncFail = 3,
}Expand description
Grammeter State
Indicates the state of the cardinal grammeter
Variants
Reset = 0
Grammeter is in reset state and not ready to be used.
Sync = 1
Automatic synchronization in progress.
Ready = 2
Grammeter has successfully synchronized with the stator
SyncFail = 3
Synchronization error!
It is likely that the differential girdlespring is not on the ‘up’ position.
Implementations